==> moonlight-1.20-2.16.15-fabric-sources.jar: net/mehvahdjukaar/moonlight/core/mixins/fabric/LocalPlayerMixin.java <==
package net.mehvahdjukaar.moonlight.core.mixins.fabric;

import com.mojang.authlib.GameProfile;
import net.mehvahdjukaar.moonlight.api.entity.IControllableVehicle;
import net.minecraft.class_1297;
import net.minecraft.class_310;
import net.minecraft.class_638;
import net.minecraft.class_742;
import net.minecraft.class_744;
import net.minecraft.class_746;
import org.spongepowered.asm.mixin.Final;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

@Mixin(class_746.class)
public abstract class LocalPlayerMixin extends class_742 {

    @Shadow
    public class_744 input;

    @Shadow @Final protected class_310 minecraft;

    protected LocalPlayerMixin(class_638 clientLevel, GameProfile gameProfile) {
        super(clientLevel, gameProfile);
    }

    @Inject(method = "aiStep", at = @At(value = "INVOKE", target = "Lnet/minecraft/client/player/Input;tick(ZF)V",
            shift = At.Shift.AFTER))
    public void onMovementInputUpdate(CallbackInfo ci) {
        class_1297 riddenEntity = this.method_5854();
        if (riddenEntity instanceof IControllableVehicle listener) {
            listener.onInputUpdate(this.input.field_3908, input.field_3906,
                    input.field_3910, input.field_3909,
                    this.minecraft.field_1690.field_1867.method_1434(), input.field_3904);
        }
    }
}

==> moonlight-1.21-2.25.0-fabric-sources.jar: net/mehvahdjukaar/moonlight/core/mixins/fabric/LocalPlayerMixin.java <==
package net.mehvahdjukaar.moonlight.core.mixins.fabric;

import com.mojang.authlib.GameProfile;
import net.fabricmc.fabric.impl.resource.conditions.conditions.AllModsLoadedResourceCondition;
import net.fabricmc.loader.impl.discovery.ModLoadCondition;
import net.mehvahdjukaar.moonlight.api.entity.IControllableVehicle;
import net.minecraft.class_1297;
import net.minecraft.class_310;
import net.minecraft.class_638;
import net.minecraft.class_742;
import net.minecraft.class_744;
import net.minecraft.class_746;
import org.spongepowered.asm.mixin.Final;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

@Mixin(class_746.class)
public abstract class LocalPlayerMixin extends class_742 {

    @Shadow
    public class_744 input;

    @Shadow @Final protected class_310 minecraft;

    protected LocalPlayerMixin(class_638 clientLevel, GameProfile gameProfile) {
        super(clientLevel, gameProfile);
    }

    @Inject(method = "aiStep", at = @At(value = "INVOKE", target = "Lnet/minecraft/client/player/Input;tick(ZF)V",
            shift = At.Shift.AFTER))
    public void onMovementInputUpdate(CallbackInfo ci) {
        class_1297 riddenEntity = this.method_5854();
        if (riddenEntity instanceof IControllableVehicle listener) {
            listener.onInputUpdate(this.input.field_3908, input.field_3906,
                    input.field_3910, input.field_3909,
                    this.minecraft.field_1690.field_1867.method_1434(), input.field_3904);
        }
    }
}
